@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Maven::Maven;
-$Maven::Maven::VERSION = '1.09';
+$Maven::Maven::VERSION = '1.10';
 # ABSTRACT: The main interface to maven
 # PODNAME: Maven::Maven
 
@@ -33,6 +33,7 @@ sub _default_agent {
 }
 
 sub _default_m2_home {
+    return unless ( $ENV{M2_HOME} );
     if ( $^O eq 'cygwin' ) {
         return Cygwin::win_to_posix_path( $ENV{M2_HOME} );
     }
@@ -56,9 +57,10 @@ sub _default_user_home {
 sub _init {
     my ( $self, %options ) = @_;
 
+    my $m2_home = $options{M2_HOME} || _default_m2_home();
     $self->{properties} = {
-        'env.M2_HOME' => $options{M2_HOME}     || _default_m2_home(),
-        'user.home'   => $options{'user.home'} || _default_user_home()
+        ( $m2_home ? ( 'env.M2_HOME' => $m2_home ) : () ),
+        'user.home' => $options{'user.home'} || _default_user_home()
     };
 
     $self->{settings} = load_settings(
@@ -189,7 +191,7 @@ Maven::Maven - The main interface to maven
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
